@@ -1,4 +1,5 @@
 import json
+import os
 import sys
 import inject
 from mcloud.events import EventBus
@@ -182,9 +183,10 @@ class Server(object):
 
     settings = inject.attr('settings')
 
-    def __init__(self, port=7080):
+    def __init__(self, port=7080, no_ssl=False):
         self.port = port
         self.clients = []
+        self.no_ssl = False
 
 
     @inlineCallbacks
@@ -277,12 +279,18 @@ class Server(object):
 
         try:
 
-            if self.settings and self.settings.ssl.enabled:
+            if not self.no_ssl and self.settings and self.settings.ssl.enabled:
 
                 from OpenSSL import SSL
 
                 from twisted.internet import ssl
 
+                print '*' * 60
+                print 'Running in secure mode'
+                print 'Ssl key:         %s' % self.settings.ssl.key
+                print 'Ssl certificate: %s' % self.settings.ssl.cert
+                print '*' * 60
+
                 myContextFactory = ssl.DefaultOpenSSLContextFactory(
                     self.settings.ssl.key, self.settings.ssl.cert
                 )
@@ -292,11 +300,16 @@ class Server(object):
 
                 # Since we have self-signed certs we have to explicitly
                 # tell the server to trust them.
-                ctx.load_verify_locations(self.settings.ssl.cert)
+
+                ctx.load_verify_locations(self.settings.ssl.ca)
 
                 reactor.listenSSL(self.port, factory, myContextFactory)
             else:
-                reactor.listenTCP(self.port, factory)
+                print '*' * 60
+                print 'INSECURE MODE'
+                print 'Running on 127.0.0.1 only'
+                print '*' * 60
+                reactor.listenTCP(self.port, factory, interface='127.0.0.1')
         except:
             log.err()
 
@@ -332,7 +345,7 @@ class MdcloudWebsocketClientProtocol(WebSocketClientProtocol):
 
 
 class Client(object):
-    def __init__(self, host='127.0.0.1', port=7080, settings=None):
+    def __init__(self, host='127.0.0.1', port=7080, settings=None, no_ssl=False):
         self.port = port
         self.host = host
         self.onc = None
@@ -340,6 +353,7 @@ class Client(object):
         self.request_id = 0
         self.request_map = {}
         self.settings = settings
+        self.no_ssl = no_ssl
 
         self.task_map = {}
 
@@ -400,11 +414,20 @@ class Client(object):
 
         self.onc = defer.Deferred()
 
-        if self.settings and self.settings.ssl.enabled:
+        key_path = os.path.expanduser('~/.mcloud/%s.key' % self.host)
+        crt_path = os.path.expanduser('~/.mcloud/%s.crt' % self.host)
+
+        if not self.no_ssl and os.path.exists(key_path) and os.path.exists(crt_path):
+
             from mcloud.ssl import CtxFactory
 
-            reactor.connectSSL(self.host, self.port, factory, CtxFactory())
+            reactor.connectSSL(self.host, self.port, factory, CtxFactory(key_path, crt_path))
         else:
+            if self.host != '127.0.0.1':
+                print '*' * 60
+                print 'Warning! Unsecure connection to remote machine.'
+                print '*' * 60
+
             reactor.connectTCP(self.host, self.port, factory)
 
         return self.onc
